@@ -1648,7 +1648,7 @@ describe('node-fetch', () => {
 
   it('should allow manual redirect handling', function () {
     this.timeout(5000)
-    const url = 'https://httpbin.org/status/302'
+    const url = `${base}redirect/302`
     const options = {
       redirect: 'manual'
     }
@@ -1656,24 +1656,8 @@ describe('node-fetch', () => {
       expect(res.status).to.equal(302)
       expect(res.url).to.equal(url)
       expect(res.type).to.equal('basic')
-      expect(res.headers.get('Location')).to.equal('/redirect/1')
+      expect(res.headers.get('Location')).to.equal('/inspect')
       expect(res.ok).to.be.false
     })
   })
-
-  // it('should not time out waiting for a response 60 seconds', function () {
-  //   this.timeout(65_000)
-  //   return fetch(`${base}timeout60s`).then(res => {
-  //     expect(res.status).to.equal(200)
-  //     expect(res.ok).to.be.true
-  //     return res.text().then(result => {
-  //       expect(result).to.equal('text')
-  //     })
-  //   })
-  // })
-
-  // it('should time out waiting for more than 300 seconds', function () {
-  //   this.timeout(305_000)
-  //   return expect(fetch(`${base}timeout300s`)).to.eventually.be.rejectedWith(TypeError)
-  // })
 })
