@@ -1,17 +1,17 @@
 'use strict'
 
-const { test } = require('tap')
+const { test, teardown } = require('tap')
 const { request, fetch, setGlobalDispatcher, getGlobalDispatcher } = require('..')
 const { InvalidArgumentError } = require('../lib/core/errors')
+const { nodeMajor } = require('../lib/core/util')
 const { readFileSync } = require('fs')
 const { join } = require('path')
 const ProxyAgent = require('../lib/proxy-agent')
+const Pool = require('../lib/pool')
 const { createServer } = require('http')
 const https = require('https')
 const proxy = require('proxy')
 
-const nodeMajor = Number(process.versions.node.split('.', 1)[0])
-
 test('should throw error when no uri is provided', (t) => {
   t.plan(2)
   t.throws(() => new ProxyAgent(), InvalidArgumentError)
@@ -73,6 +73,45 @@ test('use proxy-agent to connect through proxy', async (t) => {
   proxyAgent.close()
 })
 
+test('use proxy agent to connect through proxy using Pool', async (t) => {
+  t.plan(3)
+  const server = await buildServer()
+  const proxy = await buildProxy()
+  let resolveFirstConnect
+  let connectCount = 0
+
+  proxy.authenticate = async function (req, fn) {
+    if (++connectCount === 2) {
+      t.pass('second connect should arrive while first is still inflight')
+      resolveFirstConnect()
+      fn(null, true)
+    } else {
+      await new Promise((resolve) => {
+        resolveFirstConnect = resolve
+      })
+      fn(null, true)
+    }
+  }
+
+  server.on('request', (req, res) => {
+    res.end()
+  })
+
+  const serverUrl = `http://localhost:${server.address().port}`
+  const proxyUrl = `http://localhost:${proxy.address().port}`
+  const clientFactory = (url, options) => {
+    return new Pool(url, options)
+  }
+  const proxyAgent = new ProxyAgent({ auth: Buffer.from('user:pass').toString('base64'), uri: proxyUrl, clientFactory })
+  const firstRequest = request(`${serverUrl}`, { dispatcher: proxyAgent })
+  const secondRequest = await request(`${serverUrl}`, { dispatcher: proxyAgent })
+  t.equal((await firstRequest).statusCode, 200)
+  t.equal(secondRequest.statusCode, 200)
+  server.close()
+  proxy.close()
+  proxyAgent.close()
+})
+
 test('use proxy-agent to connect through proxy using path with params', async (t) => {
   t.plan(6)
   const server = await buildServer()
@@ -197,6 +236,39 @@ test('use proxy-agent with token', async (t) => {
   proxyAgent.close()
 })
 
+test('use proxy-agent with custom headers', async (t) => {
+  t.plan(2)
+  const server = await buildServer()
+  const proxy = await buildProxy()
+
+  const serverUrl = `http://localhost:${server.address().port}`
+  const proxyUrl = `http://localhost:${proxy.address().port}`
+  const proxyAgent = new ProxyAgent({
+    uri: proxyUrl,
+    headers: {
+      'User-Agent': 'Foobar/1.0.0'
+    }
+  })
+
+  proxy.on('connect', (req) => {
+    t.equal(req.headers['user-agent'], 'Foobar/1.0.0')
+  })
+
+  server.on('request', (req, res) => {
+    t.equal(req.headers['user-agent'], 'BarBaz/1.0.0')
+    res.end()
+  })
+
+  await request(serverUrl + '/hello?foo=bar', {
+    headers: { 'user-agent': 'BarBaz/1.0.0' },
+    dispatcher: proxyAgent
+  })
+
+  server.close()
+  proxy.close()
+  proxyAgent.close()
+})
+
 test('sending proxy-authorization in request headers should throw', async (t) => {
   t.plan(3)
   const server = await buildServer()
@@ -620,3 +692,5 @@ function buildSSLProxy () {
     server.listen(0, () => resolve(server))
   })
 }
+
+teardown(() => process.exit())
